# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.08
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.list_service_forwarders_response import ListServiceForwardersResponse  # noqa: E501
from agilicus_api.rest import ApiException

class TestListServiceForwardersResponse(unittest.TestCase):
    """ListServiceForwardersResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListServiceForwardersResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.list_service_forwarders_response.ListServiceForwardersResponse()  # noqa: E501
        if include_optional :
            return ListServiceForwardersResponse(
                service_forwarders = [
                    agilicus_api.models.service_forwarder.ServiceForwarder(
                        metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                        spec = agilicus_api.models.service_forwarder_spec.ServiceForwarderSpec(
                            name = '0', 
                            org_id = '0', 
                            bind_address = 'localhost', 
                            port = 56, 
                            protocol = 'tcp', 
                            application_service_id = '0', 
                            connector_id = '123', ), 
                        status = agilicus_api.models.service_forwarder_status.ServiceForwarderStatus(
                            connection_uri = '0', 
                            application_service = agilicus_api.models.application_service.ApplicationService(
                                created = '2015-07-07T15:49:51.230+02:00', 
                                id = '123', 
                                name = '0', 
                                org_id = '0', 
                                hostname = 'db.example.com', 
                                ipv4_addresses = [
                                    '192.0.2.1'
                                    ], 
                                name_resolution = 'static', 
                                port = 56, 
                                protocol = 'tcp', 
                                assignments = [
                                    agilicus_api.models.application_service_assignment.ApplicationServiceAssignment(
                                        app_id = '0', 
                                        environment_name = '0', 
                                        org_id = '0', )
                                    ], 
                                updated = '2015-07-07T15:49:51.230+02:00', 
                                service_type = 'vpn', 
                                service_protocol_type = 'ip', 
                                tls_enabled = True, 
                                tls_verify = True, 
                                connector_id = '123', 
                                connection_uri = '0', ), ), )
                    ], 
                limit = 56
            )
        else :
            return ListServiceForwardersResponse(
                limit = 56,
        )

    def testListServiceForwardersResponse(self):
        """Test ListServiceForwardersResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.08
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class FileSummary(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'tag': 'str',
        'label': 'str',
        'size': 'int',
        'visibility': 'FileVisibility',
        'public_url': 'str',
        'storage_path': 'str',
        'last_accessed': 'datetime',
        'created': 'datetime',
        'updated': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'tag': 'tag',
        'label': 'label',
        'size': 'size',
        'visibility': 'visibility',
        'public_url': 'public_url',
        'storage_path': 'storage_path',
        'last_accessed': 'last_accessed',
        'created': 'created',
        'updated': 'updated'
    }

    def __init__(self, id=None, name=None, tag=None, label=None, size=None, visibility=None, public_url=None, storage_path=None, last_accessed=None, created=None, updated=None, local_vars_configuration=None):  # noqa: E501
        """FileSummary - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._tag = None
        self._label = None
        self._size = None
        self._visibility = None
        self._public_url = None
        self._storage_path = None
        self._last_accessed = None
        self._created = None
        self._updated = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if tag is not None:
            self.tag = tag
        if label is not None:
            self.label = label
        if size is not None:
            self.size = size
        if visibility is not None:
            self.visibility = visibility
        if public_url is not None:
            self.public_url = public_url
        if storage_path is not None:
            self.storage_path = storage_path
        if last_accessed is not None:
            self.last_accessed = last_accessed
        if created is not None:
            self.created = created
        if updated is not None:
            self.updated = updated

    @property
    def id(self):
        """Gets the id of this FileSummary.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The id of this FileSummary.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this FileSummary.

        Unique identifier  # noqa: E501

        :param id: The id of this FileSummary.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this FileSummary.  # noqa: E501

        Name of file  # noqa: E501

        :return: The name of this FileSummary.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FileSummary.

        Name of file  # noqa: E501

        :param name: The name of this FileSummary.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 100):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def tag(self):
        """Gets the tag of this FileSummary.  # noqa: E501

        A file tag  # noqa: E501

        :return: The tag of this FileSummary.  # noqa: E501
        :rtype: str
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """Sets the tag of this FileSummary.

        A file tag  # noqa: E501

        :param tag: The tag of this FileSummary.  # noqa: E501
        :type: str
        """

        self._tag = tag

    @property
    def label(self):
        """Gets the label of this FileSummary.  # noqa: E501

        A file label  # noqa: E501

        :return: The label of this FileSummary.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this FileSummary.

        A file label  # noqa: E501

        :param label: The label of this FileSummary.  # noqa: E501
        :type: str
        """

        self._label = label

    @property
    def size(self):
        """Gets the size of this FileSummary.  # noqa: E501

        Size in bytes of the file  # noqa: E501

        :return: The size of this FileSummary.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this FileSummary.

        Size in bytes of the file  # noqa: E501

        :param size: The size of this FileSummary.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def visibility(self):
        """Gets the visibility of this FileSummary.  # noqa: E501


        :return: The visibility of this FileSummary.  # noqa: E501
        :rtype: FileVisibility
        """
        return self._visibility

    @visibility.setter
    def visibility(self, visibility):
        """Sets the visibility of this FileSummary.


        :param visibility: The visibility of this FileSummary.  # noqa: E501
        :type: FileVisibility
        """

        self._visibility = visibility

    @property
    def public_url(self):
        """Gets the public_url of this FileSummary.  # noqa: E501

        The location of the file on the internet. If present, this file can be downloaded by requesting this URI. If the file is publically visible, then no credentials need be provided.   # noqa: E501

        :return: The public_url of this FileSummary.  # noqa: E501
        :rtype: str
        """
        return self._public_url

    @public_url.setter
    def public_url(self, public_url):
        """Sets the public_url of this FileSummary.

        The location of the file on the internet. If present, this file can be downloaded by requesting this URI. If the file is publically visible, then no credentials need be provided.   # noqa: E501

        :param public_url: The public_url of this FileSummary.  # noqa: E501
        :type: str
        """

        self._public_url = public_url

    @property
    def storage_path(self):
        """Gets the storage_path of this FileSummary.  # noqa: E501

        Where the file is stored in the backend storage.  # noqa: E501

        :return: The storage_path of this FileSummary.  # noqa: E501
        :rtype: str
        """
        return self._storage_path

    @storage_path.setter
    def storage_path(self, storage_path):
        """Sets the storage_path of this FileSummary.

        Where the file is stored in the backend storage.  # noqa: E501

        :param storage_path: The storage_path of this FileSummary.  # noqa: E501
        :type: str
        """

        self._storage_path = storage_path

    @property
    def last_accessed(self):
        """Gets the last_accessed of this FileSummary.  # noqa: E501

        Time object was last accessed  # noqa: E501

        :return: The last_accessed of this FileSummary.  # noqa: E501
        :rtype: datetime
        """
        return self._last_accessed

    @last_accessed.setter
    def last_accessed(self, last_accessed):
        """Sets the last_accessed of this FileSummary.

        Time object was last accessed  # noqa: E501

        :param last_accessed: The last_accessed of this FileSummary.  # noqa: E501
        :type: datetime
        """

        self._last_accessed = last_accessed

    @property
    def created(self):
        """Gets the created of this FileSummary.  # noqa: E501

        Creation time  # noqa: E501

        :return: The created of this FileSummary.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this FileSummary.

        Creation time  # noqa: E501

        :param created: The created of this FileSummary.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def updated(self):
        """Gets the updated of this FileSummary.  # noqa: E501

        Update time  # noqa: E501

        :return: The updated of this FileSummary.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this FileSummary.

        Update time  # noqa: E501

        :param updated: The updated of this FileSummary.  # noqa: E501
        :type: datetime
        """

        self._updated = updated

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FileSummary):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FileSummary):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.08
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class AgentConnectorStats(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'metadata': 'ConnectorStatsMetadata',
        'overall_status': 'str',
        'system': 'AgentConnectorSystemStats',
        'transport': 'AgentConnectorTransportStats',
        'shares': 'AgentConnectorShareStats',
        'authz': 'AgentConnectorAuthzStats',
        'proxy': 'AgentConnectorProxyStats'
    }

    attribute_map = {
        'metadata': 'metadata',
        'overall_status': 'overall_status',
        'system': 'system',
        'transport': 'transport',
        'shares': 'shares',
        'authz': 'authz',
        'proxy': 'proxy'
    }

    def __init__(self, metadata=None, overall_status=None, system=None, transport=None, shares=None, authz=None, proxy=None, local_vars_configuration=None):  # noqa: E501
        """AgentConnectorStats - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._metadata = None
        self._overall_status = None
        self._system = None
        self._transport = None
        self._shares = None
        self._authz = None
        self._proxy = None
        self.discriminator = None

        self.metadata = metadata
        self.overall_status = overall_status
        self.system = system
        self.transport = transport
        if shares is not None:
            self.shares = shares
        if authz is not None:
            self.authz = authz
        if proxy is not None:
            self.proxy = proxy

    @property
    def metadata(self):
        """Gets the metadata of this AgentConnectorStats.  # noqa: E501


        :return: The metadata of this AgentConnectorStats.  # noqa: E501
        :rtype: ConnectorStatsMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this AgentConnectorStats.


        :param metadata: The metadata of this AgentConnectorStats.  # noqa: E501
        :type: ConnectorStatsMetadata
        """
        if self.local_vars_configuration.client_side_validation and metadata is None:  # noqa: E501
            raise ValueError("Invalid value for `metadata`, must not be `None`")  # noqa: E501

        self._metadata = metadata

    @property
    def overall_status(self):
        """Gets the overall_status of this AgentConnectorStats.  # noqa: E501

        The summary status of the Connector. - A `good` status means that no action is neccessary on this Connector - A `warn` status means that there is an issue that should be dealt with   Examples include connections restarting frequently. - A `down` status indicates that there is a service accessibility problem   that should be dealt with as soon as possible. This could mean that there is a   problem with the Connector's configuration, or the platform. - A `stale` status indicates that although there may not be anything wrong,   we haven't been able to update the status recently. This may indicate   a communications issue between Agilicus and the Connector.   # noqa: E501

        :return: The overall_status of this AgentConnectorStats.  # noqa: E501
        :rtype: str
        """
        return self._overall_status

    @overall_status.setter
    def overall_status(self, overall_status):
        """Sets the overall_status of this AgentConnectorStats.

        The summary status of the Connector. - A `good` status means that no action is neccessary on this Connector - A `warn` status means that there is an issue that should be dealt with   Examples include connections restarting frequently. - A `down` status indicates that there is a service accessibility problem   that should be dealt with as soon as possible. This could mean that there is a   problem with the Connector's configuration, or the platform. - A `stale` status indicates that although there may not be anything wrong,   we haven't been able to update the status recently. This may indicate   a communications issue between Agilicus and the Connector.   # noqa: E501

        :param overall_status: The overall_status of this AgentConnectorStats.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and overall_status is None:  # noqa: E501
            raise ValueError("Invalid value for `overall_status`, must not be `None`")  # noqa: E501
        allowed_values = ["good", "warn", "down", "stale"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and overall_status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `overall_status` ({0}), must be one of {1}"  # noqa: E501
                .format(overall_status, allowed_values)
            )

        self._overall_status = overall_status

    @property
    def system(self):
        """Gets the system of this AgentConnectorStats.  # noqa: E501


        :return: The system of this AgentConnectorStats.  # noqa: E501
        :rtype: AgentConnectorSystemStats
        """
        return self._system

    @system.setter
    def system(self, system):
        """Sets the system of this AgentConnectorStats.


        :param system: The system of this AgentConnectorStats.  # noqa: E501
        :type: AgentConnectorSystemStats
        """
        if self.local_vars_configuration.client_side_validation and system is None:  # noqa: E501
            raise ValueError("Invalid value for `system`, must not be `None`")  # noqa: E501

        self._system = system

    @property
    def transport(self):
        """Gets the transport of this AgentConnectorStats.  # noqa: E501


        :return: The transport of this AgentConnectorStats.  # noqa: E501
        :rtype: AgentConnectorTransportStats
        """
        return self._transport

    @transport.setter
    def transport(self, transport):
        """Sets the transport of this AgentConnectorStats.


        :param transport: The transport of this AgentConnectorStats.  # noqa: E501
        :type: AgentConnectorTransportStats
        """
        if self.local_vars_configuration.client_side_validation and transport is None:  # noqa: E501
            raise ValueError("Invalid value for `transport`, must not be `None`")  # noqa: E501

        self._transport = transport

    @property
    def shares(self):
        """Gets the shares of this AgentConnectorStats.  # noqa: E501


        :return: The shares of this AgentConnectorStats.  # noqa: E501
        :rtype: AgentConnectorShareStats
        """
        return self._shares

    @shares.setter
    def shares(self, shares):
        """Sets the shares of this AgentConnectorStats.


        :param shares: The shares of this AgentConnectorStats.  # noqa: E501
        :type: AgentConnectorShareStats
        """

        self._shares = shares

    @property
    def authz(self):
        """Gets the authz of this AgentConnectorStats.  # noqa: E501


        :return: The authz of this AgentConnectorStats.  # noqa: E501
        :rtype: AgentConnectorAuthzStats
        """
        return self._authz

    @authz.setter
    def authz(self, authz):
        """Sets the authz of this AgentConnectorStats.


        :param authz: The authz of this AgentConnectorStats.  # noqa: E501
        :type: AgentConnectorAuthzStats
        """

        self._authz = authz

    @property
    def proxy(self):
        """Gets the proxy of this AgentConnectorStats.  # noqa: E501


        :return: The proxy of this AgentConnectorStats.  # noqa: E501
        :rtype: AgentConnectorProxyStats
        """
        return self._proxy

    @proxy.setter
    def proxy(self, proxy):
        """Sets the proxy of this AgentConnectorStats.


        :param proxy: The proxy of this AgentConnectorStats.  # noqa: E501
        :type: AgentConnectorProxyStats
        """

        self._proxy = proxy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentConnectorStats):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AgentConnectorStats):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.08
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.policy_condition import PolicyCondition  # noqa: E501
from agilicus_api.rest import ApiException

class TestPolicyCondition(unittest.TestCase):
    """PolicyCondition unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PolicyCondition
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.policy_condition.PolicyCondition()  # noqa: E501
        if include_optional :
            return PolicyCondition(
                condition_type = 'type_client_id_list', 
                inverted = True, 
                input_is_list = True, 
                value = 'my-city-org', 
                operator = 'equals', 
                field = 'clients.name', 
                created = '2015-07-07T15:49:51.230+02:00', 
                updated = '2015-07-07T15:49:51.230+02:00'
            )
        else :
            return PolicyCondition(
                condition_type = 'type_client_id_list',
                value = 'my-city-org',
                operator = 'equals',
        )

    def testPolicyCondition(self):
        """Test PolicyCondition"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



import os
import tempfile
import agilicus
import yaml

from . import apps, context, files


def add(
    ctx,
    application,
    env_name,
    org_id=None,
    config_type=None,
    mount_src_path=None,
    username=None,
    password=None,
    share=None,
    domain=None,
    hostname=None,
    file_store_uri=None,
    filename=None,
    env_config_vars=None,
    **kwargs,
):
    token = context.get_token(ctx)
    if not org_id:
        org_id = context.get_org_id(ctx, token)

    if filename:
        _file = files.upload(
            ctx,
            filename,
            org_id=org_id,
            label=config_type,
            tag=env_name,
            name=os.path.basename(filename),
        )
        file_store_uri = f"/v1/files/{_file['id']}"

    app = apps.get_app(ctx, org_id, application, maintained=True)
    _config = agilicus.EnvironmentConfig(
        maintenance_org_id=org_id,
        config_type=config_type,
        file_store_uri=file_store_uri,
        mount_src_path=mount_src_path,
        mount_username=username,
        mount_password=password,
        mount_share=share,
        mount_domain=domain,
        mount_hostname=hostname,
        env_config_vars=env_config_vars,
        **kwargs,
    )
    apiclient = context.get_apiclient(ctx, token)
    return apiclient.application_api.add_config(app["id"], env_name, _config)


def update(
    ctx,
    application,
    env_name,
    id,
    org_id=None,
    config_type=None,
    mount_path=None,
    file_store_uri=None,
    env_config_vars=None,
    **kwargs,
):
    token = context.get_token(ctx)
    if not org_id:
        org_id = context.get_org_id(ctx, token)

    app = apps.get_app(ctx, org_id, application, maintained=True)

    apiclient = context.get_apiclient(ctx, token)
    _config = apiclient.application_api.get_config(
        app["id"], env_name, id, maintenance_org_id=org_id
    )

    _update = agilicus.EnvironmentConfig(
        maintenance_org_id=org_id,
        id=id,
        mount_path=_config.mount_path,
        config_type=_config.config_type,
        file_store_uri=_config.file_store_uri,
        env_config_vars=env_config_vars,
    )

    if mount_path:
        _update.mount_path = mount_path

    if config_type:
        _update.config_type = config_type

    if file_store_uri:
        _update.file_store_uri = file_store_uri
    return apiclient.application_api.replace_config(app["id"], env_name, id, _update)


def delete(ctx, application, env_name, id, org_id=None, **kwargs):
    token = context.get_token(ctx)
    if not org_id:
        org_id = context.get_org_id(ctx, token)

    app = apps.get_app(ctx, org_id, application, maintained=True)
    apiclient = context.get_apiclient(ctx, token)

    _config = apiclient.application_api.get_config(
        app["id"], env_name, id, maintenance_org_id=org_id
    )

    if _config.file_store_uri:
        file_id = os.path.basename(_config.file_store_uri)
        try:
            files.delete(ctx, file_id, org_id=org_id, _continue_on_error=True)
        except Exception:
            print(f"Failed to delete the {_config.file_store_uri}")

    return apiclient.application_api.delete_config(app["id"], env_name, id, org_id)


def query(ctx, application, env_name, org_id=None, **kwargs):
    token = context.get_token(ctx)
    if not org_id:
        org_id = context.get_org_id(ctx, token)

    app = apps.get_app(ctx, org_id, application, maintained=True)
    apiclient = context.get_apiclient(ctx, token)
    return apiclient.application_api.list_configs(app["id"], env_name, org_id).configs


def convert_to_env_config_var(env_config_dict):
    env_list = []
    for k, v in env_config_dict.items():
        env_var_obj = agilicus.EnvironmentConfigVar(name=k, value=v)
        env_list.append(env_var_obj)
    return env_list


class EnvVarConfigObj:
    def __init__(self, ctx, application, env_name, org_id=None, secret=False):
        self.ctx = ctx
        self.application = application
        self.env_name = env_name
        self.org_id = org_id
        if secret:
            self.env_file = "secret-env.yaml"
            self.config_type = "secret_env"
        else:
            self.env_file = "config-env.yaml"
            self.config_type = "configmap_env"
        self.env_config = None
        self.old_file_envs = {}
        self.old_env_configs = {}
        self.env_vars = {}
        self.env_var_list = []
        self.build_env_list()

    def get_env_list(self):
        return self.env_var_list

    def get_old_env(self, env_config_vars):
        self.old_env_configs = {}
        if env_config_vars:
            for env in env_config_vars:
                self.old_env_configs[env.name] = env.value

    def merge_env(self, file_env, env_config):
        self.env_vars = file_env
        self.env_vars.update(env_config)

    def build_env_list(self):
        configs = query(self.ctx, self.application, self.env_name, self.org_id)
        for config in configs:
            if config.config_type.upper() == self.config_type.upper():
                if config.file_store_uri:
                    with tempfile.TemporaryDirectory() as tempdir:
                        destination = os.path.join(tempdir, self.env_file)
                        files.download(
                            self.ctx,
                            os.path.basename(config.file_store_uri),
                            org_id=self.org_id,
                            destination=destination,
                        )
                        with open(destination) as stream:
                            self.old_file_envs = yaml.safe_load(stream)
                self.get_old_env(config.env_config_vars)
                self.merge_env(self.old_file_envs, self.old_env_configs)
                self.env_var_list = convert_to_env_config_var(self.env_vars)
                self.env_config = config
                return

    def write_env_vars(self, data):
        self.env_vars.update(data)

    def write_env_list(self):
        self.env_var_list = convert_to_env_config_var(self.env_vars)
        filename = None
        if self.env_config:
            delete(
                self.ctx,
                self.application,
                self.env_name,
                self.env_config.id,
                self.org_id,
            )
        with tempfile.TemporaryDirectory() as tempdir:
            filename = os.path.join(tempdir, self.env_file)
            with open(filename, "w") as outfile:
                yaml.dump(self.env_vars, outfile, default_flow_style=False)
            self.env_config = add(
                self.ctx,
                self.application,
                self.env_name,
                org_id=self.org_id,
                config_type=self.config_type,
                filename=None,
                file_store_uri=None,
                env_config_vars=self.env_var_list,
            )

    def add_env_var(self, env_name, env_value):
        env_data = {}
        env_data[env_name] = env_value
        self.write_env_vars(env_data)
        self.write_env_list()

    def del_env_var(self, env_var_name):
        self.env_vars.pop(env_var_name, None)
        self.write_env_list()

    def update_env_var(self, env_config_name, env_config_value):
        env_data = {}
        env_data[env_config_name] = env_config_value
        self.write_env_vars(env_data)
        self.write_env_list()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.08
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class Service(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'created': 'datetime',
        'id': 'str',
        'name': 'str',
        'description': 'str',
        'org_id': 'str',
        'contact_email': 'str',
        'roles': 'RoleList',
        'definitions': 'list[Definition]',
        'base_url': 'str',
        'updated': 'datetime'
    }

    attribute_map = {
        'created': 'created',
        'id': 'id',
        'name': 'name',
        'description': 'description',
        'org_id': 'org_id',
        'contact_email': 'contact_email',
        'roles': 'roles',
        'definitions': 'definitions',
        'base_url': 'base_url',
        'updated': 'updated'
    }

    def __init__(self, created=None, id=None, name=None, description=None, org_id=None, contact_email=None, roles=None, definitions=None, base_url=None, updated=None, local_vars_configuration=None):  # noqa: E501
        """Service - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._created = None
        self._id = None
        self._name = None
        self._description = None
        self._org_id = None
        self._contact_email = None
        self._roles = None
        self._definitions = None
        self._base_url = None
        self._updated = None
        self.discriminator = None

        if created is not None:
            self.created = created
        if id is not None:
            self.id = id
        self.name = name
        if description is not None:
            self.description = description
        self.org_id = org_id
        if contact_email is not None:
            self.contact_email = contact_email
        if roles is not None:
            self.roles = roles
        if definitions is not None:
            self.definitions = definitions
        self.base_url = base_url
        if updated is not None:
            self.updated = updated

    @property
    def created(self):
        """Gets the created of this Service.  # noqa: E501

        Creation time  # noqa: E501

        :return: The created of this Service.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this Service.

        Creation time  # noqa: E501

        :param created: The created of this Service.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def id(self):
        """Gets the id of this Service.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The id of this Service.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Service.

        Unique identifier  # noqa: E501

        :param id: The id of this Service.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this Service.  # noqa: E501

        Service name. Must be unique accross all Applications and Services.  # noqa: E501

        :return: The name of this Service.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Service.

        Service name. Must be unique accross all Applications and Services.  # noqa: E501

        :param name: The name of this Service.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 100):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this Service.  # noqa: E501

        Service description text  # noqa: E501

        :return: The description of this Service.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Service.

        Service description text  # noqa: E501

        :param description: The description of this Service.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def org_id(self):
        """Gets the org_id of this Service.  # noqa: E501

        organisation id  # noqa: E501

        :return: The org_id of this Service.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this Service.

        organisation id  # noqa: E501

        :param org_id: The org_id of this Service.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and org_id is None:  # noqa: E501
            raise ValueError("Invalid value for `org_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                org_id is not None and len(org_id) > 40):
            raise ValueError("Invalid value for `org_id`, length must be less than or equal to `40`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                org_id is not None and len(org_id) < 1):
            raise ValueError("Invalid value for `org_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._org_id = org_id

    @property
    def contact_email(self):
        """Gets the contact_email of this Service.  # noqa: E501

        Administrator contact email  # noqa: E501

        :return: The contact_email of this Service.  # noqa: E501
        :rtype: str
        """
        return self._contact_email

    @contact_email.setter
    def contact_email(self, contact_email):
        """Sets the contact_email of this Service.

        Administrator contact email  # noqa: E501

        :param contact_email: The contact_email of this Service.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                contact_email is not None and len(contact_email) > 100):
            raise ValueError("Invalid value for `contact_email`, length must be less than or equal to `100`")  # noqa: E501

        self._contact_email = contact_email

    @property
    def roles(self):
        """Gets the roles of this Service.  # noqa: E501


        :return: The roles of this Service.  # noqa: E501
        :rtype: RoleList
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """Sets the roles of this Service.


        :param roles: The roles of this Service.  # noqa: E501
        :type: RoleList
        """

        self._roles = roles

    @property
    def definitions(self):
        """Gets the definitions of this Service.  # noqa: E501

        List of definitions  # noqa: E501

        :return: The definitions of this Service.  # noqa: E501
        :rtype: list[Definition]
        """
        return self._definitions

    @definitions.setter
    def definitions(self, definitions):
        """Sets the definitions of this Service.

        List of definitions  # noqa: E501

        :param definitions: The definitions of this Service.  # noqa: E501
        :type: list[Definition]
        """

        self._definitions = definitions

    @property
    def base_url(self):
        """Gets the base_url of this Service.  # noqa: E501

        The URL which forms the base of this service. This value will be joined with the paths in the rules for this service to form its authorization model.   # noqa: E501

        :return: The base_url of this Service.  # noqa: E501
        :rtype: str
        """
        return self._base_url

    @base_url.setter
    def base_url(self, base_url):
        """Sets the base_url of this Service.

        The URL which forms the base of this service. This value will be joined with the paths in the rules for this service to form its authorization model.   # noqa: E501

        :param base_url: The base_url of this Service.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and base_url is None:  # noqa: E501
            raise ValueError("Invalid value for `base_url`, must not be `None`")  # noqa: E501

        self._base_url = base_url

    @property
    def updated(self):
        """Gets the updated of this Service.  # noqa: E501

        Update time  # noqa: E501

        :return: The updated of this Service.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this Service.

        Update time  # noqa: E501

        :param updated: The updated of this Service.  # noqa: E501
        :type: datetime
        """

        self._updated = updated

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Service):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Service):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.08
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from agilicus_api.api_client import ApiClient
from agilicus_api.exceptions import (
    ApiTypeError,
    ApiValueError
)


class ResourcesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def list_resources(self, **kwargs):  # noqa: E501
        """List all Resources  # noqa: E501

        List all Resources matching the provided query parameters. Perform keyset pagination by setting the page_at_id parameter to the id for the next page to fetch. Set it to `\"\"` to start from the beginning.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_resources(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int limit: limit the number of rows in the response
        :param str org_id: Organisation Unique identifier
        :param str resource_type: The type of resource to query for
        :param str name_slug: The slug of the resource to query for
        :param str name: The name of the resource to query for
        :param str resource_id: The id of the resource to query for
        :param str page_at_id: Pagination based query with the id as the key. To get the initial entries supply an empty string. On subsequent requests, supply the `page_at_id` field from the list response. 
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ListResourcesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.list_resources_with_http_info(**kwargs)  # noqa: E501

    def list_resources_with_http_info(self, **kwargs):  # noqa: E501
        """List all Resources  # noqa: E501

        List all Resources matching the provided query parameters. Perform keyset pagination by setting the page_at_id parameter to the id for the next page to fetch. Set it to `\"\"` to start from the beginning.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_resources_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int limit: limit the number of rows in the response
        :param str org_id: Organisation Unique identifier
        :param str resource_type: The type of resource to query for
        :param str name_slug: The slug of the resource to query for
        :param str name: The name of the resource to query for
        :param str resource_id: The id of the resource to query for
        :param str page_at_id: Pagination based query with the id as the key. To get the initial entries supply an empty string. On subsequent requests, supply the `page_at_id` field from the list response. 
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ListResourcesResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['limit', 'org_id', 'resource_type', 'name_slug', 'name', 'resource_id', 'page_at_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_resources" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] > 500:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `list_resources`, must be a value less than or equal to `500`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] < 1:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `list_resources`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'org_id' in local_var_params and local_var_params['org_id'] is not None:  # noqa: E501
            query_params.append(('org_id', local_var_params['org_id']))  # noqa: E501
        if 'resource_type' in local_var_params and local_var_params['resource_type'] is not None:  # noqa: E501
            query_params.append(('resource_type', local_var_params['resource_type']))  # noqa: E501
        if 'name_slug' in local_var_params and local_var_params['name_slug'] is not None:  # noqa: E501
            query_params.append(('name_slug', local_var_params['name_slug']))  # noqa: E501
        if 'name' in local_var_params and local_var_params['name'] is not None:  # noqa: E501
            query_params.append(('name', local_var_params['name']))  # noqa: E501
        if 'resource_id' in local_var_params and local_var_params['resource_id'] is not None:  # noqa: E501
            query_params.append(('resource_id', local_var_params['resource_id']))  # noqa: E501
        if 'page_at_id' in local_var_params and local_var_params['page_at_id'] is not None:  # noqa: E501
            query_params.append(('page_at_id', local_var_params['page_at_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/resources', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListResourcesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.08
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.list_agent_connector_response import ListAgentConnectorResponse  # noqa: E501
from agilicus_api.rest import ApiException

class TestListAgentConnectorResponse(unittest.TestCase):
    """ListAgentConnectorResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListAgentConnectorResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.list_agent_connector_response.ListAgentConnectorResponse()  # noqa: E501
        if include_optional :
            return ListAgentConnectorResponse(
                agent_connectors = [
                    agilicus_api.models.agent_connector.AgentConnector(
                        metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                        spec = agilicus_api.models.agent_connector_spec.AgentConnectorSpec(
                            name = '0', 
                            name_slug = 'a', 
                            org_id = '123', 
                            max_number_connections = 0, 
                            connection_uri = '0', 
                            service_account_required = True, 
                            local_authentication_enabled = False, ), 
                        status = agilicus_api.models.agent_connector_status.AgentConnectorStatus(
                            application_services = [
                                agilicus_api.models.application_service.ApplicationService(
                                    created = '2015-07-07T15:49:51.230+02:00', 
                                    id = '123', 
                                    name = '0', 
                                    org_id = '0', 
                                    hostname = 'db.example.com', 
                                    ipv4_addresses = [
                                        '192.0.2.1'
                                        ], 
                                    name_resolution = 'static', 
                                    port = 56, 
                                    protocol = 'tcp', 
                                    assignments = [
                                        agilicus_api.models.application_service_assignment.ApplicationServiceAssignment(
                                            app_id = '0', 
                                            environment_name = '0', 
                                            org_id = '0', )
                                        ], 
                                    updated = '2015-07-07T15:49:51.230+02:00', 
                                    service_type = 'vpn', 
                                    service_protocol_type = 'ip', 
                                    tls_enabled = True, 
                                    tls_verify = True, 
                                    connector_id = '123', 
                                    connection_uri = '0', )
                                ], 
                            service_account_id = '0', 
                            info = agilicus_api.models.agent_connector_info.AgentConnectorInfo(
                                local_authentication_enabled = False, 
                                connections_info = [
                                    agilicus_api.models.agent_connector_connection_info.AgentConnectorConnectionInfo(
                                        connection_uri = 'wss://my-app.example.com/.agilcus-agent', 
                                        connection_location = 'my-app.example.com', 
                                        connection_path = '/.agilicus-agent', 
                                        connection_org_id = 'asda93oidl2xZ6', 
                                        connection_app_name = 'my-app', 
                                        is_an_auth_service = True, 
                                        end_to_end_tls = True, 
                                        max_number_connections = 0, 
                                        ip_services = [
                                            agilicus_api.models.application_service.ApplicationService(
                                                created = '2015-07-07T15:49:51.230+02:00', 
                                                id = '123', 
                                                name = '0', 
                                                org_id = '0', 
                                                hostname = 'db.example.com', 
                                                name_resolution = 'static', 
                                                port = 56, 
                                                protocol = 'tcp', 
                                                updated = '2015-07-07T15:49:51.230+02:00', 
                                                service_type = 'vpn', 
                                                service_protocol_type = 'ip', 
                                                tls_enabled = True, 
                                                tls_verify = True, 
                                                connector_id = '123', 
                                                connection_uri = '0', )
                                            ], 
                                        file_share_services = [
                                            agilicus_api.models.file_share_service.FileShareService(
                                                spec = agilicus_api.models.file_share_service_spec.FileShareServiceSpec(
                                                    name = 'share1', 
                                                    share_name = 'share1', 
                                                    org_id = '123', 
                                                    local_path = '/home/agilicus/public/share1', 
                                                    connector_id = '123', 
                                                    share_index = 1, 
                                                    transport_end_to_end_tls = True, 
                                                    transport_base_domain = '0', ), )
                                            ], 
                                        application_config = agilicus_api.models.application_config.ApplicationConfig(
                                            authentication_config = agilicus_api.models.application_authentication_config.ApplicationAuthenticationConfig(
                                                application_handles_authentication = False, 
                                                session_secret = 'Gns5ZPCvXGjzrtB672HAxfoSQ0dmqriSgiQf6uEQSBU=', ), 
                                            oidc_config = agilicus_api.models.oidc_proxy_config.OIDCProxyConfig(
                                                headers = agilicus_api.models.oidc_proxy_header.OIDCProxyHeader(
                                                    domain_substitution = agilicus_api.models.oidc_proxy_domain_substitution.OIDCProxyDomainSubstitution(
                                                        standard_headers = agilicus_api.models.oidc_proxy_standard_header.OIDCProxyStandardHeader(
                                                            location = True, 
                                                            origin = True, 
                                                            host = True, ), 
                                                        other_headers = [
                                                            agilicus_api.models.oidc_proxy_header_mapping.OIDCProxyHeaderMapping(
                                                                name = 'Accept-Encoding', 
                                                                value = '*', )
                                                            ], ), 
                                                    header_overrides = agilicus_api.models.oidc_proxy_header_override.OIDCProxyHeaderOverride(
                                                        request = agilicus_api.models.oidc_proxy_header_user_config.OIDCProxyHeaderUserConfig(
                                                            set = [
                                                                agilicus_api.models.oidc_proxy_header_mapping.OIDCProxyHeaderMapping(
                                                                    name = 'Accept-Encoding', 
                                                                    value = '*', )
                                                                ], 
                                                            add = [
                                                                agilicus_api.models.oidc_proxy_header_mapping.OIDCProxyHeaderMapping(
                                                                    name = 'Accept-Encoding', 
                                                                    value = '*', )
                                                                ], 
                                                            remove = [
                                                                agilicus_api.models.oidc_proxy_header_name.OIDCProxyHeaderName(
                                                                    name = '0', )
                                                                ], ), 
                                                        response = agilicus_api.models.oidc_proxy_header_user_config.OIDCProxyHeaderUserConfig(), ), ), 
                                                domain_mapping = agilicus_api.models.oidc_proxy_domain_mapping.OIDCProxyDomainMapping(
                                                    primary_external_name = 'app-1.cloud.egov.city', 
                                                    primary_internal_name = 'app-1.internal', 
                                                    other_mappings = [
                                                        agilicus_api.models.oidc_proxy_domain_name_mapping.OIDCProxyDomainNameMapping(
                                                            internal_name = 'local_test_app', 
                                                            external_name = 'app-1', )
                                                        ], ), 
                                                auth = agilicus_api.models.oidc_auth_config.OIDCAuthConfig(
                                                    auth_enabled = True, 
                                                    client_id = 'admin-portal', 
                                                    issuer = 'https://auth.cloud.egov.city', 
                                                    logout_url = '/login/logout.cfm', 
                                                    scopes = [
                                                        agilicus_api.models.oidc_proxy_scope.OIDCProxyScope(
                                                            name = 'urn:agilicus:app:app-1:owner', )
                                                        ], 
                                                    path_config = agilicus_api.models.oidc_auth_path_config.OIDCAuthPathConfig(
                                                        included_paths = [{"path":"/login"}], 
                                                        excluded_paths = [{"path":"/logout"}], ), ), 
                                                content_manipulation = agilicus_api.models.oidc_proxy_content_manipulation.OIDCProxyContentManipulation(
                                                    media_types = [
                                                        agilicus_api.models.oidc_content_type.OIDCContentType(
                                                            name = 'text/css', )
                                                        ], ), 
                                                upstream_config = agilicus_api.models.oidc_proxy_upstream_config.OIDCProxyUpstreamConfig(
                                                    scheme = 'https', 
                                                    hostname = 'httpbin.org', ), ), ), )
                                    ], 
                                allow_list = {
                                    'key' : [
                                        agilicus_api.models.allow_rule_compiled.AllowRuleCompiled(
                                            paths = [
                                                '/.*'
                                                ], 
                                            methods = ["get"], 
                                            any_auth_user = True, )
                                        ]
                                    }, 
                                authz_public_key = 'apublickey', 
                                application_service_uri = '0', 
                                tunnel_uri = 'wss://agent-server.ca-1.agilicus.ca/.agilicus-agent/control', 
                                service_forwarders = [
                                    agilicus_api.models.service_forwarder.ServiceForwarder(
                                        spec = agilicus_api.models.service_forwarder_spec.ServiceForwarderSpec(
                                            name = '0', 
                                            org_id = '0', 
                                            bind_address = 'localhost', 
                                            port = 56, 
                                            protocol = 'tcp', 
                                            application_service_id = '0', 
                                            connector_id = '123', ), )
                                    ], 
                                from_service_forwarders = [
                                    agilicus_api.models.service_forwarder.ServiceForwarder(
                                        spec = agilicus_api.models.service_forwarder_spec.ServiceForwarderSpec(
                                            name = '0', 
                                            org_id = '0', 
                                            bind_address = 'localhost', 
                                            port = 56, 
                                            protocol = 'tcp', 
                                            application_service_id = '0', 
                                            connector_id = '123', ), )
                                    ], ), 
                            stats = {"metadata":{"creation_time":"2020-07-07T15:40:46.010Z","collection_time":"2020-07-07T15:40:44.020Z","receipt_time":"2020-07-07T15:40:46.020Z"},"overall_status":"good","system":{"os_version":"5.4.0","os_uptime":15623,"agent_uptime":15000,"agent_version":"v0.29.5 8e4fe7281219aa02dcc088154b7e7e3fc279f259","agent_connector_id":"as3asldlt3a","agent_connector_org_id":"dO04ldlfwe9a3l"},"transport":{"active_connections":5,"target_number_connections":5,"connection_start_count":10,"connection_stop_count":5}}, 
                            local_authentication = agilicus_api.models.agent_local_auth_info.AgentLocalAuthInfo(
                                org_id = '123', 
                                local_authentication_public_key = '-----BEGIN PRIVATE KEY-----\nActualKeyContents\n-----END PRIVATE KEY-----\n', ), ), )
                    ], 
                limit = 56, 
                page_at_id = 'sd0X4asd3as'
            )
        else :
            return ListAgentConnectorResponse(
                agent_connectors = [
                    agilicus_api.models.agent_connector.AgentConnector(
                        metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                        spec = agilicus_api.models.agent_connector_spec.AgentConnectorSpec(
                            name = '0', 
                            name_slug = 'a', 
                            org_id = '123', 
                            max_number_connections = 0, 
                            connection_uri = '0', 
                            service_account_required = True, 
                            local_authentication_enabled = False, ), 
                        status = agilicus_api.models.agent_connector_status.AgentConnectorStatus(
                            application_services = [
                                agilicus_api.models.application_service.ApplicationService(
                                    created = '2015-07-07T15:49:51.230+02:00', 
                                    id = '123', 
                                    name = '0', 
                                    org_id = '0', 
                                    hostname = 'db.example.com', 
                                    ipv4_addresses = [
                                        '192.0.2.1'
                                        ], 
                                    name_resolution = 'static', 
                                    port = 56, 
                                    protocol = 'tcp', 
                                    assignments = [
                                        agilicus_api.models.application_service_assignment.ApplicationServiceAssignment(
                                            app_id = '0', 
                                            environment_name = '0', 
                                            org_id = '0', )
                                        ], 
                                    updated = '2015-07-07T15:49:51.230+02:00', 
                                    service_type = 'vpn', 
                                    service_protocol_type = 'ip', 
                                    tls_enabled = True, 
                                    tls_verify = True, 
                                    connector_id = '123', 
                                    connection_uri = '0', )
                                ], 
                            service_account_id = '0', 
                            info = agilicus_api.models.agent_connector_info.AgentConnectorInfo(
                                local_authentication_enabled = False, 
                                connections_info = [
                                    agilicus_api.models.agent_connector_connection_info.AgentConnectorConnectionInfo(
                                        connection_uri = 'wss://my-app.example.com/.agilcus-agent', 
                                        connection_location = 'my-app.example.com', 
                                        connection_path = '/.agilicus-agent', 
                                        connection_org_id = 'asda93oidl2xZ6', 
                                        connection_app_name = 'my-app', 
                                        is_an_auth_service = True, 
                                        end_to_end_tls = True, 
                                        max_number_connections = 0, 
                                        ip_services = [
                                            agilicus_api.models.application_service.ApplicationService(
                                                created = '2015-07-07T15:49:51.230+02:00', 
                                                id = '123', 
                                                name = '0', 
                                                org_id = '0', 
                                                hostname = 'db.example.com', 
                                                name_resolution = 'static', 
                                                port = 56, 
                                                protocol = 'tcp', 
                                                updated = '2015-07-07T15:49:51.230+02:00', 
                                                service_type = 'vpn', 
                                                service_protocol_type = 'ip', 
                                                tls_enabled = True, 
                                                tls_verify = True, 
                                                connector_id = '123', 
                                                connection_uri = '0', )
                                            ], 
                                        file_share_services = [
                                            agilicus_api.models.file_share_service.FileShareService(
                                                spec = agilicus_api.models.file_share_service_spec.FileShareServiceSpec(
                                                    name = 'share1', 
                                                    share_name = 'share1', 
                                                    org_id = '123', 
                                                    local_path = '/home/agilicus/public/share1', 
                                                    connector_id = '123', 
                                                    share_index = 1, 
                                                    transport_end_to_end_tls = True, 
                                                    transport_base_domain = '0', ), )
                                            ], 
                                        application_config = agilicus_api.models.application_config.ApplicationConfig(
                                            authentication_config = agilicus_api.models.application_authentication_config.ApplicationAuthenticationConfig(
                                                application_handles_authentication = False, 
                                                session_secret = 'Gns5ZPCvXGjzrtB672HAxfoSQ0dmqriSgiQf6uEQSBU=', ), 
                                            oidc_config = agilicus_api.models.oidc_proxy_config.OIDCProxyConfig(
                                                headers = agilicus_api.models.oidc_proxy_header.OIDCProxyHeader(
                                                    domain_substitution = agilicus_api.models.oidc_proxy_domain_substitution.OIDCProxyDomainSubstitution(
                                                        standard_headers = agilicus_api.models.oidc_proxy_standard_header.OIDCProxyStandardHeader(
                                                            location = True, 
                                                            origin = True, 
                                                            host = True, ), 
                                                        other_headers = [
                                                            agilicus_api.models.oidc_proxy_header_mapping.OIDCProxyHeaderMapping(
                                                                name = 'Accept-Encoding', 
                                                                value = '*', )
                                                            ], ), 
                                                    header_overrides = agilicus_api.models.oidc_proxy_header_override.OIDCProxyHeaderOverride(
                                                        request = agilicus_api.models.oidc_proxy_header_user_config.OIDCProxyHeaderUserConfig(
                                                            set = [
                                                                agilicus_api.models.oidc_proxy_header_mapping.OIDCProxyHeaderMapping(
                                                                    name = 'Accept-Encoding', 
                                                                    value = '*', )
                                                                ], 
                                                            add = [
                                                                agilicus_api.models.oidc_proxy_header_mapping.OIDCProxyHeaderMapping(
                                                                    name = 'Accept-Encoding', 
                                                                    value = '*', )
                                                                ], 
                                                            remove = [
                                                                agilicus_api.models.oidc_proxy_header_name.OIDCProxyHeaderName(
                                                                    name = '0', )
                                                                ], ), 
                                                        response = agilicus_api.models.oidc_proxy_header_user_config.OIDCProxyHeaderUserConfig(), ), ), 
                                                domain_mapping = agilicus_api.models.oidc_proxy_domain_mapping.OIDCProxyDomainMapping(
                                                    primary_external_name = 'app-1.cloud.egov.city', 
                                                    primary_internal_name = 'app-1.internal', 
                                                    other_mappings = [
                                                        agilicus_api.models.oidc_proxy_domain_name_mapping.OIDCProxyDomainNameMapping(
                                                            internal_name = 'local_test_app', 
                                                            external_name = 'app-1', )
                                                        ], ), 
                                                auth = agilicus_api.models.oidc_auth_config.OIDCAuthConfig(
                                                    auth_enabled = True, 
                                                    client_id = 'admin-portal', 
                                                    issuer = 'https://auth.cloud.egov.city', 
                                                    logout_url = '/login/logout.cfm', 
                                                    scopes = [
                                                        agilicus_api.models.oidc_proxy_scope.OIDCProxyScope(
                                                            name = 'urn:agilicus:app:app-1:owner', )
                                                        ], 
                                                    path_config = agilicus_api.models.oidc_auth_path_config.OIDCAuthPathConfig(
                                                        included_paths = [{"path":"/login"}], 
                                                        excluded_paths = [{"path":"/logout"}], ), ), 
                                                content_manipulation = agilicus_api.models.oidc_proxy_content_manipulation.OIDCProxyContentManipulation(
                                                    media_types = [
                                                        agilicus_api.models.oidc_content_type.OIDCContentType(
                                                            name = 'text/css', )
                                                        ], ), 
                                                upstream_config = agilicus_api.models.oidc_proxy_upstream_config.OIDCProxyUpstreamConfig(
                                                    scheme = 'https', 
                                                    hostname = 'httpbin.org', ), ), ), )
                                    ], 
                                allow_list = {
                                    'key' : [
                                        agilicus_api.models.allow_rule_compiled.AllowRuleCompiled(
                                            paths = [
                                                '/.*'
                                                ], 
                                            methods = ["get"], 
                                            any_auth_user = True, )
                                        ]
                                    }, 
                                authz_public_key = 'apublickey', 
                                application_service_uri = '0', 
                                tunnel_uri = 'wss://agent-server.ca-1.agilicus.ca/.agilicus-agent/control', 
                                service_forwarders = [
                                    agilicus_api.models.service_forwarder.ServiceForwarder(
                                        spec = agilicus_api.models.service_forwarder_spec.ServiceForwarderSpec(
                                            name = '0', 
                                            org_id = '0', 
                                            bind_address = 'localhost', 
                                            port = 56, 
                                            protocol = 'tcp', 
                                            application_service_id = '0', 
                                            connector_id = '123', ), )
                                    ], 
                                from_service_forwarders = [
                                    agilicus_api.models.service_forwarder.ServiceForwarder(
                                        spec = agilicus_api.models.service_forwarder_spec.ServiceForwarderSpec(
                                            name = '0', 
                                            org_id = '0', 
                                            bind_address = 'localhost', 
                                            port = 56, 
                                            protocol = 'tcp', 
                                            application_service_id = '0', 
                                            connector_id = '123', ), )
                                    ], ), 
                            stats = {"metadata":{"creation_time":"2020-07-07T15:40:46.010Z","collection_time":"2020-07-07T15:40:44.020Z","receipt_time":"2020-07-07T15:40:46.020Z"},"overall_status":"good","system":{"os_version":"5.4.0","os_uptime":15623,"agent_uptime":15000,"agent_version":"v0.29.5 8e4fe7281219aa02dcc088154b7e7e3fc279f259","agent_connector_id":"as3asldlt3a","agent_connector_org_id":"dO04ldlfwe9a3l"},"transport":{"active_connections":5,"target_number_connections":5,"connection_start_count":10,"connection_stop_count":5}}, 
                            local_authentication = agilicus_api.models.agent_local_auth_info.AgentLocalAuthInfo(
                                org_id = '123', 
                                local_authentication_public_key = '-----BEGIN PRIVATE KEY-----\nActualKeyContents\n-----END PRIVATE KEY-----\n', ), ), )
                    ],
                limit = 56,
        )

    def testListAgentConnectorResponse(self):
        """Test ListAgentConnectorResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.08
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.user_file_share_access_info_status import UserFileShareAccessInfoStatus  # noqa: E501
from agilicus_api.rest import ApiException

class TestUserFileShareAccessInfoStatus(unittest.TestCase):
    """UserFileShareAccessInfoStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UserFileShareAccessInfoStatus
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.user_file_share_access_info_status.UserFileShareAccessInfoStatus()  # noqa: E501
        if include_optional :
            return UserFileShareAccessInfoStatus(
                user_id = 'tuU7smH86zAXMl76sua6xQ', 
                org_id = 'IAsl3dl40aSsfLKiU76', 
                org_name = 'egov', 
                parent_org_id = 'G99q3lasls29wsk', 
                parent_org_name = 'root', 
                share_id = '123', 
                share_name = 'public', 
                share_url = 'https://files.cloud.egov.city/public', 
                access_level = 'requested', 
                roles = [
                    '0'
                    ]
            )
        else :
            return UserFileShareAccessInfoStatus(
                user_id = 'tuU7smH86zAXMl76sua6xQ',
                org_id = 'IAsl3dl40aSsfLKiU76',
                org_name = 'egov',
                share_id = '123',
                share_name = 'public',
                share_url = 'https://files.cloud.egov.city/public',
                access_level = 'requested',
        )

    def testUserFileShareAccessInfoStatus(self):
        """Test UserFileShareAccessInfoStatus"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.08
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class CombinedRulesStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'app_id': 'str',
        'org_id': 'str',
        'role_id': 'str',
        'role_name': 'str',
        'rules': 'list[RuleV2]',
        'scope': 'RuleScopeEnum'
    }

    attribute_map = {
        'app_id': 'app_id',
        'org_id': 'org_id',
        'role_id': 'role_id',
        'role_name': 'role_name',
        'rules': 'rules',
        'scope': 'scope'
    }

    def __init__(self, app_id=None, org_id=None, role_id=None, role_name=None, rules=None, scope=None, local_vars_configuration=None):  # noqa: E501
        """CombinedRulesStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._app_id = None
        self._org_id = None
        self._role_id = None
        self._role_name = None
        self._rules = None
        self._scope = None
        self.discriminator = None

        if app_id is not None:
            self.app_id = app_id
        if org_id is not None:
            self.org_id = org_id
        if role_id is not None:
            self.role_id = role_id
        if role_name is not None:
            self.role_name = role_name
        if rules is not None:
            self.rules = rules
        if scope is not None:
            self.scope = scope

    @property
    def app_id(self):
        """Gets the app_id of this CombinedRulesStatus.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The app_id of this CombinedRulesStatus.  # noqa: E501
        :rtype: str
        """
        return self._app_id

    @app_id.setter
    def app_id(self, app_id):
        """Sets the app_id of this CombinedRulesStatus.

        Unique identifier  # noqa: E501

        :param app_id: The app_id of this CombinedRulesStatus.  # noqa: E501
        :type: str
        """

        self._app_id = app_id

    @property
    def org_id(self):
        """Gets the org_id of this CombinedRulesStatus.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The org_id of this CombinedRulesStatus.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this CombinedRulesStatus.

        Unique identifier  # noqa: E501

        :param org_id: The org_id of this CombinedRulesStatus.  # noqa: E501
        :type: str
        """

        self._org_id = org_id

    @property
    def role_id(self):
        """Gets the role_id of this CombinedRulesStatus.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The role_id of this CombinedRulesStatus.  # noqa: E501
        :rtype: str
        """
        return self._role_id

    @role_id.setter
    def role_id(self, role_id):
        """Sets the role_id of this CombinedRulesStatus.

        Unique identifier  # noqa: E501

        :param role_id: The role_id of this CombinedRulesStatus.  # noqa: E501
        :type: str
        """

        self._role_id = role_id

    @property
    def role_name(self):
        """Gets the role_name of this CombinedRulesStatus.  # noqa: E501

        The name of the role under which these rules were combined. If no role was associated with the rules, will be empty.   # noqa: E501

        :return: The role_name of this CombinedRulesStatus.  # noqa: E501
        :rtype: str
        """
        return self._role_name

    @role_name.setter
    def role_name(self, role_name):
        """Sets the role_name of this CombinedRulesStatus.

        The name of the role under which these rules were combined. If no role was associated with the rules, will be empty.   # noqa: E501

        :param role_name: The role_name of this CombinedRulesStatus.  # noqa: E501
        :type: str
        """

        self._role_name = role_name

    @property
    def rules(self):
        """Gets the rules of this CombinedRulesStatus.  # noqa: E501

        The rules combined together by the common property indicated by scope or role_id   # noqa: E501

        :return: The rules of this CombinedRulesStatus.  # noqa: E501
        :rtype: list[RuleV2]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """Sets the rules of this CombinedRulesStatus.

        The rules combined together by the common property indicated by scope or role_id   # noqa: E501

        :param rules: The rules of this CombinedRulesStatus.  # noqa: E501
        :type: list[RuleV2]
        """

        self._rules = rules

    @property
    def scope(self):
        """Gets the scope of this CombinedRulesStatus.  # noqa: E501


        :return: The scope of this CombinedRulesStatus.  # noqa: E501
        :rtype: RuleScopeEnum
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this CombinedRulesStatus.


        :param scope: The scope of this CombinedRulesStatus.  # noqa: E501
        :type: RuleScopeEnum
        """

        self._scope = scope

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CombinedRulesStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CombinedRulesStatus):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.08
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.api_key_introspect_response import APIKeyIntrospectResponse  # noqa: E501
from agilicus_api.rest import ApiException

class TestAPIKeyIntrospectResponse(unittest.TestCase):
    """APIKeyIntrospectResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test APIKeyIntrospectResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.api_key_introspect_response.APIKeyIntrospectResponse()  # noqa: E501
        if include_optional :
            return APIKeyIntrospectResponse(
                sub_org_results = [
                    agilicus_api.models.token.Token(
                        sub = '123', 
                        sub_email = 'foo@example.com', 
                        org = '123', 
                        root_org = '123', 
                        roles = {"app-1":["viewer"],"app-2":["owner"]}, 
                        jti = '123', 
                        iat = '0', 
                        exp = '0', 
                        hosts = [
                            agilicus_api.models.host_permissions.HostPermissions(
                                upstream_host = '0', 
                                app_id = '123', 
                                admin_org_id = '123', 
                                allowed_list = [
                                    agilicus_api.models.rendered_rule.RenderedRule(
                                        methods = [
                                            'get'
                                            ], 
                                        paths = [
                                            '0'
                                            ], 
                                        query_parameters = [
                                            agilicus_api.models.rendered_query_parameter.RenderedQueryParameter(
                                                name = '0', 
                                                exact_match = '0', )
                                            ], 
                                        body = agilicus_api.models.rendered_rule_body.RenderedRuleBody(
                                            json = [
                                                agilicus_api.models.json_body_constraint.JSONBodyConstraint(
                                                    name = '0', 
                                                    exact_match = '0', 
                                                    match_type = 'string', 
                                                    pointer = '/foo/0/a~1b/2', )
                                                ], ), )
                                    ], )
                            ], 
                        aud = [
                            '0'
                            ], 
                        session = '123', 
                        scopes = [
                            'urn:agilicus:users:owner'
                            ], )
                    ], 
                primary_token = agilicus_api.models.token.Token(
                    sub = '123', 
                    sub_email = 'foo@example.com', 
                    org = '123', 
                    root_org = '123', 
                    roles = {"app-1":["viewer"],"app-2":["owner"]}, 
                    jti = '123', 
                    iat = '0', 
                    exp = '0', 
                    hosts = [
                        agilicus_api.models.host_permissions.HostPermissions(
                            upstream_host = '0', 
                            app_id = '123', 
                            admin_org_id = '123', 
                            allowed_list = [
                                agilicus_api.models.rendered_rule.RenderedRule(
                                    methods = [
                                        'get'
                                        ], 
                                    paths = [
                                        '0'
                                        ], 
                                    query_parameters = [
                                        agilicus_api.models.rendered_query_parameter.RenderedQueryParameter(
                                            name = '0', 
                                            exact_match = '0', )
                                        ], 
                                    body = agilicus_api.models.rendered_rule_body.RenderedRuleBody(
                                        json = [
                                            agilicus_api.models.json_body_constraint.JSONBodyConstraint(
                                                name = '0', 
                                                exact_match = '0', 
                                                match_type = 'string', 
                                                pointer = '/foo/0/a~1b/2', )
                                            ], ), )
                                ], )
                        ], 
                    aud = [
                        '0'
                        ], 
                    session = '123', 
                    scopes = [
                        'urn:agilicus:users:owner'
                        ], ), 
                raw_token = '0'
            )
        else :
            return APIKeyIntrospectResponse(
                sub_org_results = [
                    agilicus_api.models.token.Token(
                        sub = '123', 
                        sub_email = 'foo@example.com', 
                        org = '123', 
                        root_org = '123', 
                        roles = {"app-1":["viewer"],"app-2":["owner"]}, 
                        jti = '123', 
                        iat = '0', 
                        exp = '0', 
                        hosts = [
                            agilicus_api.models.host_permissions.HostPermissions(
                                upstream_host = '0', 
                                app_id = '123', 
                                admin_org_id = '123', 
                                allowed_list = [
                                    agilicus_api.models.rendered_rule.RenderedRule(
                                        methods = [
                                            'get'
                                            ], 
                                        paths = [
                                            '0'
                                            ], 
                                        query_parameters = [
                                            agilicus_api.models.rendered_query_parameter.RenderedQueryParameter(
                                                name = '0', 
                                                exact_match = '0', )
                                            ], 
                                        body = agilicus_api.models.rendered_rule_body.RenderedRuleBody(
                                            json = [
                                                agilicus_api.models.json_body_constraint.JSONBodyConstraint(
                                                    name = '0', 
                                                    exact_match = '0', 
                                                    match_type = 'string', 
                                                    pointer = '/foo/0/a~1b/2', )
                                                ], ), )
                                    ], )
                            ], 
                        aud = [
                            '0'
                            ], 
                        session = '123', 
                        scopes = [
                            'urn:agilicus:users:owner'
                            ], )
                    ],
                primary_token = agilicus_api.models.token.Token(
                    sub = '123', 
                    sub_email = 'foo@example.com', 
                    org = '123', 
                    root_org = '123', 
                    roles = {"app-1":["viewer"],"app-2":["owner"]}, 
                    jti = '123', 
                    iat = '0', 
                    exp = '0', 
                    hosts = [
                        agilicus_api.models.host_permissions.HostPermissions(
                            upstream_host = '0', 
                            app_id = '123', 
                            admin_org_id = '123', 
                            allowed_list = [
                                agilicus_api.models.rendered_rule.RenderedRule(
                                    methods = [
                                        'get'
                                        ], 
                                    paths = [
                                        '0'
                                        ], 
                                    query_parameters = [
                                        agilicus_api.models.rendered_query_parameter.RenderedQueryParameter(
                                            name = '0', 
                                            exact_match = '0', )
                                        ], 
                                    body = agilicus_api.models.rendered_rule_body.RenderedRuleBody(
                                        json = [
                                            agilicus_api.models.json_body_constraint.JSONBodyConstraint(
                                                name = '0', 
                                                exact_match = '0', 
                                                match_type = 'string', 
                                                pointer = '/foo/0/a~1b/2', )
                                            ], ), )
                                ], )
                        ], 
                    aud = [
                        '0'
                        ], 
                    session = '123', 
                    scopes = [
                        'urn:agilicus:users:owner'
                        ], ),
        )

    def testAPIKeyIntrospectResponse(self):
        """Test APIKeyIntrospectResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.08
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import agilicus_api
from agilicus_api.api.catalogues_api import CataloguesApi  # noqa: E501
from agilicus_api.rest import ApiException


class TestCataloguesApi(unittest.TestCase):
    """CataloguesApi unit test stubs"""

    def setUp(self):
        self.api = agilicus_api.api.catalogues_api.CataloguesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_catalogue(self):
        """Test case for create_catalogue

        create a catalogue  # noqa: E501
        """
        pass

    def test_create_catalogue_entry(self):
        """Test case for create_catalogue_entry

        create a catalogue entry  # noqa: E501
        """
        pass

    def test_delete_catalogue(self):
        """Test case for delete_catalogue

        Delete the catalogue specified by catalogue_id  # noqa: E501
        """
        pass

    def test_delete_catalogue_entry(self):
        """Test case for delete_catalogue_entry

        Delete the catalogue specified by catalogue_entry_id  # noqa: E501
        """
        pass

    def test_get_catalogue(self):
        """Test case for get_catalogue

        Get the catalogue specified by catalogue_id  # noqa: E501
        """
        pass

    def test_get_catalogue_entry(self):
        """Test case for get_catalogue_entry

        Get the catalogue entry by id for the given catalogue  # noqa: E501
        """
        pass

    def test_list_all_catalogue_entries(self):
        """Test case for list_all_catalogue_entries

        List all catalogue entries independant of the catalogue they belong to  # noqa: E501
        """
        pass

    def test_list_catalogue_entries(self):
        """Test case for list_catalogue_entries

        List catalogue entries in the catalogue  # noqa: E501
        """
        pass

    def test_list_catalogues(self):
        """Test case for list_catalogues

        List all catalogues  # noqa: E501
        """
        pass

    def test_replace_catalogue(self):
        """Test case for replace_catalogue

        Replace the catalogue specified by catalogue_id  # noqa: E501
        """
        pass

    def test_replace_catalogue_entry(self):
        """Test case for replace_catalogue_entry

        Replace the catalogue entry specified by catalogue_entry_id  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.08
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.list_file_share_services_response import ListFileShareServicesResponse  # noqa: E501
from agilicus_api.rest import ApiException

class TestListFileShareServicesResponse(unittest.TestCase):
    """ListFileShareServicesResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListFileShareServicesResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.list_file_share_services_response.ListFileShareServicesResponse()  # noqa: E501
        if include_optional :
            return ListFileShareServicesResponse(
                file_share_services = [
                    agilicus_api.models.file_share_service.FileShareService(
                        metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                        spec = agilicus_api.models.file_share_service_spec.FileShareServiceSpec(
                            name = 'share1', 
                            share_name = 'share1', 
                            org_id = '123', 
                            local_path = '/home/agilicus/public/share1', 
                            connector_id = '123', 
                            share_index = 1, 
                            transport_end_to_end_tls = True, 
                            transport_base_domain = '0', ), 
                        status = agilicus_api.models.file_share_service_status.FileShareServiceStatus(
                            share_base_app_name = '0', 
                            instance_id = 'asdas9Gk4asdaTH', 
                            instance_org_id = '39ddfGAaslts8qX', 
                            share_uri = 'https://share-4.cloud.egov.city/', ), )
                    ], 
                limit = 56
            )
        else :
            return ListFileShareServicesResponse(
                limit = 56,
        )

    def testListFileShareServicesResponse(self):
        """Test ListFileShareServicesResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.08
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class AgentConnectorConnectionInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'connection_uri': 'str',
        'connection_location': 'str',
        'connection_path': 'str',
        'connection_org_id': 'str',
        'connection_app_name': 'str',
        'is_an_auth_service': 'bool',
        'end_to_end_tls': 'bool',
        'max_number_connections': 'int',
        'ip_services': 'list[ApplicationService]',
        'file_share_services': 'list[FileShareService]',
        'application_config': 'ApplicationConfig'
    }

    attribute_map = {
        'connection_uri': 'connection_uri',
        'connection_location': 'connection_location',
        'connection_path': 'connection_path',
        'connection_org_id': 'connection_org_id',
        'connection_app_name': 'connection_app_name',
        'is_an_auth_service': 'is_an_auth_service',
        'end_to_end_tls': 'end_to_end_tls',
        'max_number_connections': 'max_number_connections',
        'ip_services': 'ip_services',
        'file_share_services': 'file_share_services',
        'application_config': 'application_config'
    }

    def __init__(self, connection_uri=None, connection_location=None, connection_path=None, connection_org_id=None, connection_app_name=None, is_an_auth_service=False, end_to_end_tls=None, max_number_connections=16, ip_services=None, file_share_services=None, application_config=None, local_vars_configuration=None):  # noqa: E501
        """AgentConnectorConnectionInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._connection_uri = None
        self._connection_location = None
        self._connection_path = None
        self._connection_org_id = None
        self._connection_app_name = None
        self._is_an_auth_service = None
        self._end_to_end_tls = None
        self._max_number_connections = None
        self._ip_services = None
        self._file_share_services = None
        self._application_config = None
        self.discriminator = None

        if connection_uri is not None:
            self.connection_uri = connection_uri
        if connection_location is not None:
            self.connection_location = connection_location
        if connection_path is not None:
            self.connection_path = connection_path
        if connection_org_id is not None:
            self.connection_org_id = connection_org_id
        if connection_app_name is not None:
            self.connection_app_name = connection_app_name
        if is_an_auth_service is not None:
            self.is_an_auth_service = is_an_auth_service
        if end_to_end_tls is not None:
            self.end_to_end_tls = end_to_end_tls
        if max_number_connections is not None:
            self.max_number_connections = max_number_connections
        if ip_services is not None:
            self.ip_services = ip_services
        if file_share_services is not None:
            self.file_share_services = file_share_services
        if application_config is not None:
            self.application_config = application_config

    @property
    def connection_uri(self):
        """Gets the connection_uri of this AgentConnectorConnectionInfo.  # noqa: E501

        The URI used to establish a connection to the connector.  # noqa: E501

        :return: The connection_uri of this AgentConnectorConnectionInfo.  # noqa: E501
        :rtype: str
        """
        return self._connection_uri

    @connection_uri.setter
    def connection_uri(self, connection_uri):
        """Sets the connection_uri of this AgentConnectorConnectionInfo.

        The URI used to establish a connection to the connector.  # noqa: E501

        :param connection_uri: The connection_uri of this AgentConnectorConnectionInfo.  # noqa: E501
        :type: str
        """

        self._connection_uri = connection_uri

    @property
    def connection_location(self):
        """Gets the connection_location of this AgentConnectorConnectionInfo.  # noqa: E501

        The location (e.g. fully qualified domain name) of the connection. While this matches the location in the `connection_uri`, it is provided separately for convenience.   # noqa: E501

        :return: The connection_location of this AgentConnectorConnectionInfo.  # noqa: E501
        :rtype: str
        """
        return self._connection_location

    @connection_location.setter
    def connection_location(self, connection_location):
        """Sets the connection_location of this AgentConnectorConnectionInfo.

        The location (e.g. fully qualified domain name) of the connection. While this matches the location in the `connection_uri`, it is provided separately for convenience.   # noqa: E501

        :param connection_location: The connection_location of this AgentConnectorConnectionInfo.  # noqa: E501
        :type: str
        """

        self._connection_location = connection_location

    @property
    def connection_path(self):
        """Gets the connection_path of this AgentConnectorConnectionInfo.  # noqa: E501

        The path of the connection. While this matches the path in the `connection_uri`, it is provided separately for convenience.   # noqa: E501

        :return: The connection_path of this AgentConnectorConnectionInfo.  # noqa: E501
        :rtype: str
        """
        return self._connection_path

    @connection_path.setter
    def connection_path(self, connection_path):
        """Sets the connection_path of this AgentConnectorConnectionInfo.

        The path of the connection. While this matches the path in the `connection_uri`, it is provided separately for convenience.   # noqa: E501

        :param connection_path: The connection_path of this AgentConnectorConnectionInfo.  # noqa: E501
        :type: str
        """

        self._connection_path = connection_path

    @property
    def connection_org_id(self):
        """Gets the connection_org_id of this AgentConnectorConnectionInfo.  # noqa: E501

        The identifier for the organisation hosting the server side of this connection.   # noqa: E501

        :return: The connection_org_id of this AgentConnectorConnectionInfo.  # noqa: E501
        :rtype: str
        """
        return self._connection_org_id

    @connection_org_id.setter
    def connection_org_id(self, connection_org_id):
        """Sets the connection_org_id of this AgentConnectorConnectionInfo.

        The identifier for the organisation hosting the server side of this connection.   # noqa: E501

        :param connection_org_id: The connection_org_id of this AgentConnectorConnectionInfo.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                connection_org_id is not None and len(connection_org_id) > 40):
            raise ValueError("Invalid value for `connection_org_id`, length must be less than or equal to `40`")  # noqa: E501

        self._connection_org_id = connection_org_id

    @property
    def connection_app_name(self):
        """Gets the connection_app_name of this AgentConnectorConnectionInfo.  # noqa: E501

        The name of the Application (if any) hosting the server side of this connection. Note that not all servers will be hosted by an Application, in which case this will be empty.   # noqa: E501

        :return: The connection_app_name of this AgentConnectorConnectionInfo.  # noqa: E501
        :rtype: str
        """
        return self._connection_app_name

    @connection_app_name.setter
    def connection_app_name(self, connection_app_name):
        """Sets the connection_app_name of this AgentConnectorConnectionInfo.

        The name of the Application (if any) hosting the server side of this connection. Note that not all servers will be hosted by an Application, in which case this will be empty.   # noqa: E501

        :param connection_app_name: The connection_app_name of this AgentConnectorConnectionInfo.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                connection_app_name is not None and len(connection_app_name) > 63):
            raise ValueError("Invalid value for `connection_app_name`, length must be less than or equal to `63`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                connection_app_name is not None and len(connection_app_name) < 1):
            raise ValueError("Invalid value for `connection_app_name`, length must be greater than or equal to `1`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                connection_app_name is not None and not re.search(r'^[a-zA-Z0-9-:]+$', connection_app_name)):  # noqa: E501
            raise ValueError(r"Invalid value for `connection_app_name`, must be a follow pattern or equal to `/^[a-zA-Z0-9-:]+$/`")  # noqa: E501

        self._connection_app_name = connection_app_name

    @property
    def is_an_auth_service(self):
        """Gets the is_an_auth_service of this AgentConnectorConnectionInfo.  # noqa: E501

        Indicates that the connection is exposing an authentication service   # noqa: E501

        :return: The is_an_auth_service of this AgentConnectorConnectionInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_an_auth_service

    @is_an_auth_service.setter
    def is_an_auth_service(self, is_an_auth_service):
        """Sets the is_an_auth_service of this AgentConnectorConnectionInfo.

        Indicates that the connection is exposing an authentication service   # noqa: E501

        :param is_an_auth_service: The is_an_auth_service of this AgentConnectorConnectionInfo.  # noqa: E501
        :type: bool
        """

        self._is_an_auth_service = is_an_auth_service

    @property
    def end_to_end_tls(self):
        """Gets the end_to_end_tls of this AgentConnectorConnectionInfo.  # noqa: E501

        Controls if the connection is end to end TLS.   # noqa: E501

        :return: The end_to_end_tls of this AgentConnectorConnectionInfo.  # noqa: E501
        :rtype: bool
        """
        return self._end_to_end_tls

    @end_to_end_tls.setter
    def end_to_end_tls(self, end_to_end_tls):
        """Sets the end_to_end_tls of this AgentConnectorConnectionInfo.

        Controls if the connection is end to end TLS.   # noqa: E501

        :param end_to_end_tls: The end_to_end_tls of this AgentConnectorConnectionInfo.  # noqa: E501
        :type: bool
        """

        self._end_to_end_tls = end_to_end_tls

    @property
    def max_number_connections(self):
        """Gets the max_number_connections of this AgentConnectorConnectionInfo.  # noqa: E501

        The maximum number of connections to maintain to the cluster when stable. Note that this value may be exceeded during times of reconfiguration. A value of zero means that the connection is effectively unused by this Secure Agent.   # noqa: E501

        :return: The max_number_connections of this AgentConnectorConnectionInfo.  # noqa: E501
        :rtype: int
        """
        return self._max_number_connections

    @max_number_connections.setter
    def max_number_connections(self, max_number_connections):
        """Sets the max_number_connections of this AgentConnectorConnectionInfo.

        The maximum number of connections to maintain to the cluster when stable. Note that this value may be exceeded during times of reconfiguration. A value of zero means that the connection is effectively unused by this Secure Agent.   # noqa: E501

        :param max_number_connections: The max_number_connections of this AgentConnectorConnectionInfo.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                max_number_connections is not None and max_number_connections > 64):  # noqa: E501
            raise ValueError("Invalid value for `max_number_connections`, must be a value less than or equal to `64`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                max_number_connections is not None and max_number_connections < 0):  # noqa: E501
            raise ValueError("Invalid value for `max_number_connections`, must be a value greater than or equal to `0`")  # noqa: E501

        self._max_number_connections = max_number_connections

    @property
    def ip_services(self):
        """Gets the ip_services of this AgentConnectorConnectionInfo.  # noqa: E501

        The list of ip services associated with this connection  # noqa: E501

        :return: The ip_services of this AgentConnectorConnectionInfo.  # noqa: E501
        :rtype: list[ApplicationService]
        """
        return self._ip_services

    @ip_services.setter
    def ip_services(self, ip_services):
        """Sets the ip_services of this AgentConnectorConnectionInfo.

        The list of ip services associated with this connection  # noqa: E501

        :param ip_services: The ip_services of this AgentConnectorConnectionInfo.  # noqa: E501
        :type: list[ApplicationService]
        """

        self._ip_services = ip_services

    @property
    def file_share_services(self):
        """Gets the file_share_services of this AgentConnectorConnectionInfo.  # noqa: E501

        The list of fileshare services associated with this connection  # noqa: E501

        :return: The file_share_services of this AgentConnectorConnectionInfo.  # noqa: E501
        :rtype: list[FileShareService]
        """
        return self._file_share_services

    @file_share_services.setter
    def file_share_services(self, file_share_services):
        """Sets the file_share_services of this AgentConnectorConnectionInfo.

        The list of fileshare services associated with this connection  # noqa: E501

        :param file_share_services: The file_share_services of this AgentConnectorConnectionInfo.  # noqa: E501
        :type: list[FileShareService]
        """

        self._file_share_services = file_share_services

    @property
    def application_config(self):
        """Gets the application_config of this AgentConnectorConnectionInfo.  # noqa: E501


        :return: The application_config of this AgentConnectorConnectionInfo.  # noqa: E501
        :rtype: ApplicationConfig
        """
        return self._application_config

    @application_config.setter
    def application_config(self, application_config):
        """Sets the application_config of this AgentConnectorConnectionInfo.


        :param application_config: The application_config of this AgentConnectorConnectionInfo.  # noqa: E501
        :type: ApplicationConfig
        """

        self._application_config = application_config

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentConnectorConnectionInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AgentConnectorConnectionInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.08
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.agent_connector_per_share_stats import AgentConnectorPerShareStats  # noqa: E501
from agilicus_api.rest import ApiException

class TestAgentConnectorPerShareStats(unittest.TestCase):
    """AgentConnectorPerShareStats unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AgentConnectorPerShareStats
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.agent_connector_per_share_stats.AgentConnectorPerShareStats()  # noqa: E501
        if include_optional :
            return AgentConnectorPerShareStats(
                share_prefix = '/public', 
                share_id = '5s930sdfsdlA', 
                local_path = '/home/user/shared', 
                total_requests = 5132, 
                successful_requests = 5102, 
                failed_requests = 30, 
                bytes_sent = 30458101, 
                bytes_received = 9574339, 
                share_start_time = '2020-07-07T15:55:52.230Z'
            )
        else :
            return AgentConnectorPerShareStats(
                share_prefix = '/public',
                share_id = '5s930sdfsdlA',
                local_path = '/home/user/shared',
                total_requests = 5132,
                successful_requests = 5102,
                failed_requests = 30,
                bytes_sent = 30458101,
                bytes_received = 9574339,
                share_start_time = '2020-07-07T15:55:52.230Z',
        )

    def testAgentConnectorPerShareStats(self):
        """Test AgentConnectorPerShareStats"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.08
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class ServiceForwarderSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'org_id': 'str',
        'bind_address': 'str',
        'port': 'int',
        'protocol': 'str',
        'application_service_id': 'str',
        'connector_id': 'str'
    }

    attribute_map = {
        'name': 'name',
        'org_id': 'org_id',
        'bind_address': 'bind_address',
        'port': 'port',
        'protocol': 'protocol',
        'application_service_id': 'application_service_id',
        'connector_id': 'connector_id'
    }

    def __init__(self, name=None, org_id=None, bind_address=None, port=None, protocol='tcp', application_service_id=None, connector_id=None, local_vars_configuration=None):  # noqa: E501
        """ServiceForwarderSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._org_id = None
        self._bind_address = None
        self._port = None
        self._protocol = None
        self._application_service_id = None
        self._connector_id = None
        self.discriminator = None

        self.name = name
        self.org_id = org_id
        if bind_address is not None:
            self.bind_address = bind_address
        self.port = port
        if protocol is not None:
            self.protocol = protocol
        self.application_service_id = application_service_id
        self.connector_id = connector_id

    @property
    def name(self):
        """Gets the name of this ServiceForwarderSpec.  # noqa: E501

        The name of the service forwarder. This value must be unique within an organisation.   # noqa: E501

        :return: The name of this ServiceForwarderSpec.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ServiceForwarderSpec.

        The name of the service forwarder. This value must be unique within an organisation.   # noqa: E501

        :param name: The name of this ServiceForwarderSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def org_id(self):
        """Gets the org_id of this ServiceForwarderSpec.  # noqa: E501

        The organisation which owns this service forwarder.  # noqa: E501

        :return: The org_id of this ServiceForwarderSpec.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this ServiceForwarderSpec.

        The organisation which owns this service forwarder.  # noqa: E501

        :param org_id: The org_id of this ServiceForwarderSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and org_id is None:  # noqa: E501
            raise ValueError("Invalid value for `org_id`, must not be `None`")  # noqa: E501

        self._org_id = org_id

    @property
    def bind_address(self):
        """Gets the bind_address of this ServiceForwarderSpec.  # noqa: E501

        The local bind address that local applications will forward to in order to access the service forwarder.  bind_address default is localhost.   # noqa: E501

        :return: The bind_address of this ServiceForwarderSpec.  # noqa: E501
        :rtype: str
        """
        return self._bind_address

    @bind_address.setter
    def bind_address(self, bind_address):
        """Sets the bind_address of this ServiceForwarderSpec.

        The local bind address that local applications will forward to in order to access the service forwarder.  bind_address default is localhost.   # noqa: E501

        :param bind_address: The bind_address of this ServiceForwarderSpec.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                bind_address is not None and len(bind_address) > 255):
            raise ValueError("Invalid value for `bind_address`, length must be less than or equal to `255`")  # noqa: E501

        self._bind_address = bind_address

    @property
    def port(self):
        """Gets the port of this ServiceForwarderSpec.  # noqa: E501

        The transport-layer port on which to access the service forwarder. exclusiveMinimum: 0 exclusiveMaximum: 65536   # noqa: E501

        :return: The port of this ServiceForwarderSpec.  # noqa: E501
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this ServiceForwarderSpec.

        The transport-layer port on which to access the service forwarder. exclusiveMinimum: 0 exclusiveMaximum: 65536   # noqa: E501

        :param port: The port of this ServiceForwarderSpec.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and port is None:  # noqa: E501
            raise ValueError("Invalid value for `port`, must not be `None`")  # noqa: E501

        self._port = port

    @property
    def protocol(self):
        """Gets the protocol of this ServiceForwarderSpec.  # noqa: E501

        The transport-layer protocol being fowarded to the remote application service.   # noqa: E501

        :return: The protocol of this ServiceForwarderSpec.  # noqa: E501
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """Sets the protocol of this ServiceForwarderSpec.

        The transport-layer protocol being fowarded to the remote application service.   # noqa: E501

        :param protocol: The protocol of this ServiceForwarderSpec.  # noqa: E501
        :type: str
        """
        allowed_values = ["tcp"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and protocol not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `protocol` ({0}), must be one of {1}"  # noqa: E501
                .format(protocol, allowed_values)
            )

        self._protocol = protocol

    @property
    def application_service_id(self):
        """Gets the application_service_id of this ServiceForwarderSpec.  # noqa: E501

        The application service id that this service forwarder connects to.   # noqa: E501

        :return: The application_service_id of this ServiceForwarderSpec.  # noqa: E501
        :rtype: str
        """
        return self._application_service_id

    @application_service_id.setter
    def application_service_id(self, application_service_id):
        """Sets the application_service_id of this ServiceForwarderSpec.

        The application service id that this service forwarder connects to.   # noqa: E501

        :param application_service_id: The application_service_id of this ServiceForwarderSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and application_service_id is None:  # noqa: E501
            raise ValueError("Invalid value for `application_service_id`, must not be `None`")  # noqa: E501

        self._application_service_id = application_service_id

    @property
    def connector_id(self):
        """Gets the connector_id of this ServiceForwarderSpec.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The connector_id of this ServiceForwarderSpec.  # noqa: E501
        :rtype: str
        """
        return self._connector_id

    @connector_id.setter
    def connector_id(self, connector_id):
        """Sets the connector_id of this ServiceForwarderSpec.

        Unique identifier  # noqa: E501

        :param connector_id: The connector_id of this ServiceForwarderSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and connector_id is None:  # noqa: E501
            raise ValueError("Invalid value for `connector_id`, must not be `None`")  # noqa: E501

        self._connector_id = connector_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServiceForwarderSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ServiceForwarderSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.08
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.web_auth_n_enrollment_spec import WebAuthNEnrollmentSpec  # noqa: E501
from agilicus_api.rest import ApiException

class TestWebAuthNEnrollmentSpec(unittest.TestCase):
    """WebAuthNEnrollmentSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test WebAuthNEnrollmentSpec
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.web_auth_n_enrollment_spec.WebAuthNEnrollmentSpec()  # noqa: E501
        if include_optional :
            return WebAuthNEnrollmentSpec(
                user_id = '123', 
                relying_party_id = '123', 
                attestation_format = 'platform', 
                attestation_conveyance = 'direct', 
                user_verification = 'discouraged'
            )
        else :
            return WebAuthNEnrollmentSpec(
                user_id = '123',
                relying_party_id = '123',
        )

    def testWebAuthNEnrollmentSpec(self):
        """Test WebAuthNEnrollmentSpec"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.08
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.user_summary import UserSummary  # noqa: E501
from agilicus_api.rest import ApiException

class TestUserSummary(unittest.TestCase):
    """UserSummary unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UserSummary
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.user_summary.UserSummary()  # noqa: E501
        if include_optional :
            return UserSummary(
                id = '123', 
                external_id = '123', 
                enabled = False, 
                status = 'active', 
                first_name = 'Alice', 
                last_name = 'Kim', 
                email = 'foo@example.com', 
                provider = 'Google', 
                roles = {"app-1":["viewer"],"app-2":["owner"]}, 
                org_id = '123', 
                type = 'user', 
                created = '2015-07-07T15:49:51.230+02:00', 
                updated = '2015-07-07T15:49:51.230+02:00', 
                auto_created = True, 
                upstream_user_identities = [
                    agilicus_api.models.upstream_user_identity.UpstreamUserIdentity(
                        metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                        spec = agilicus_api.models.upstream_user_identity_spec.UpstreamUserIdentitySpec(
                            upstream_user_id = 'aa-bb-cc-11-22-33', 
                            upstream_idp_id = 'https://auth.cloud.egov.city', 
                            local_user_id = 'tuU7smH86zAXMl76sua6xQ', ), )
                    ], 
                cascade = True
            )
        else :
            return UserSummary(
        )

    def testUserSummary(self):
        """Test UserSummary"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.08
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class UserMetadataSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'user_id': 'str',
        'org_id': 'str',
        'app_id': 'str',
        'name': 'str',
        'data_type': 'str',
        'data': 'str'
    }

    attribute_map = {
        'user_id': 'user_id',
        'org_id': 'org_id',
        'app_id': 'app_id',
        'name': 'name',
        'data_type': 'data_type',
        'data': 'data'
    }

    def __init__(self, user_id=None, org_id=None, app_id=None, name=None, data_type=None, data=None, local_vars_configuration=None):  # noqa: E501
        """UserMetadataSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._user_id = None
        self._org_id = None
        self._app_id = None
        self._name = None
        self._data_type = None
        self._data = None
        self.discriminator = None

        self.user_id = user_id
        self.org_id = org_id
        self.app_id = app_id
        if name is not None:
            self.name = name
        if data_type is not None:
            self.data_type = data_type
        if data is not None:
            self.data = data

    @property
    def user_id(self):
        """Gets the user_id of this UserMetadataSpec.  # noqa: E501

        The unique id of the User to which this record applies.   # noqa: E501

        :return: The user_id of this UserMetadataSpec.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this UserMetadataSpec.

        The unique id of the User to which this record applies.   # noqa: E501

        :param user_id: The user_id of this UserMetadataSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                user_id is not None and len(user_id) > 40):
            raise ValueError("Invalid value for `user_id`, length must be less than or equal to `40`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                user_id is not None and len(user_id) < 1):
            raise ValueError("Invalid value for `user_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._user_id = user_id

    @property
    def org_id(self):
        """Gets the org_id of this UserMetadataSpec.  # noqa: E501

        The unique id of the Organisation to which this record applies.   # noqa: E501

        :return: The org_id of this UserMetadataSpec.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this UserMetadataSpec.

        The unique id of the Organisation to which this record applies.   # noqa: E501

        :param org_id: The org_id of this UserMetadataSpec.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                org_id is not None and len(org_id) > 40):
            raise ValueError("Invalid value for `org_id`, length must be less than or equal to `40`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                org_id is not None and len(org_id) < 1):
            raise ValueError("Invalid value for `org_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._org_id = org_id

    @property
    def app_id(self):
        """Gets the app_id of this UserMetadataSpec.  # noqa: E501

        The unique id of the application to which this record applies.   # noqa: E501

        :return: The app_id of this UserMetadataSpec.  # noqa: E501
        :rtype: str
        """
        return self._app_id

    @app_id.setter
    def app_id(self, app_id):
        """Sets the app_id of this UserMetadataSpec.

        The unique id of the application to which this record applies.   # noqa: E501

        :param app_id: The app_id of this UserMetadataSpec.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                app_id is not None and len(app_id) > 40):
            raise ValueError("Invalid value for `app_id`, length must be less than or equal to `40`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                app_id is not None and len(app_id) < 1):
            raise ValueError("Invalid value for `app_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._app_id = app_id

    @property
    def name(self):
        """Gets the name of this UserMetadataSpec.  # noqa: E501

        A descriptive name for this metadata entry  # noqa: E501

        :return: The name of this UserMetadataSpec.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UserMetadataSpec.

        A descriptive name for this metadata entry  # noqa: E501

        :param name: The name of this UserMetadataSpec.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 100):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")  # noqa: E501

        self._name = name

    @property
    def data_type(self):
        """Gets the data_type of this UserMetadataSpec.  # noqa: E501

        The type of data present in the configuration. This informs consumers of how to use the data present. The 'json' type means no internal interpretation is done, it is a string-in/string-out. On query this can be deep-merged with member groups.   # noqa: E501

        :return: The data_type of this UserMetadataSpec.  # noqa: E501
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this UserMetadataSpec.

        The type of data present in the configuration. This informs consumers of how to use the data present. The 'json' type means no internal interpretation is done, it is a string-in/string-out. On query this can be deep-merged with member groups.   # noqa: E501

        :param data_type: The data_type of this UserMetadataSpec.  # noqa: E501
        :type: str
        """
        allowed_values = ["mfa_enrollment_expiry", "user_app_data", "user_org_data", "json"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and data_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `data_type` ({0}), must be one of {1}"  # noqa: E501
                .format(data_type, allowed_values)
            )

        self._data_type = data_type

    @property
    def data(self):
        """Gets the data of this UserMetadataSpec.  # noqa: E501

        The string representation of the data. This value is interpretted differently based on the data_type  # noqa: E501

        :return: The data of this UserMetadataSpec.  # noqa: E501
        :rtype: str
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this UserMetadataSpec.

        The string representation of the data. This value is interpretted differently based on the data_type  # noqa: E501

        :param data: The data of this UserMetadataSpec.  # noqa: E501
        :type: str
        """

        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserMetadataSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserMetadataSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.08
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class AgentConnectorInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'local_authentication_enabled': 'bool',
        'connections_info': 'list[AgentConnectorConnectionInfo]',
        'allow_list': 'AllowMapCompiled',
        'authz_public_key': 'str',
        'application_service_uri': 'str',
        'tunnel_uri': 'str',
        'service_forwarders': 'list[ServiceForwarder]',
        'from_service_forwarders': 'list[ServiceForwarder]'
    }

    attribute_map = {
        'local_authentication_enabled': 'local_authentication_enabled',
        'connections_info': 'connections_info',
        'allow_list': 'allow_list',
        'authz_public_key': 'authz_public_key',
        'application_service_uri': 'application_service_uri',
        'tunnel_uri': 'tunnel_uri',
        'service_forwarders': 'service_forwarders',
        'from_service_forwarders': 'from_service_forwarders'
    }

    def __init__(self, local_authentication_enabled=None, connections_info=None, allow_list=None, authz_public_key=None, application_service_uri=None, tunnel_uri=None, service_forwarders=None, from_service_forwarders=None, local_vars_configuration=None):  # noqa: E501
        """AgentConnectorInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._local_authentication_enabled = None
        self._connections_info = None
        self._allow_list = None
        self._authz_public_key = None
        self._application_service_uri = None
        self._tunnel_uri = None
        self._service_forwarders = None
        self._from_service_forwarders = None
        self.discriminator = None

        if local_authentication_enabled is not None:
            self.local_authentication_enabled = local_authentication_enabled
        if connections_info is not None:
            self.connections_info = connections_info
        if allow_list is not None:
            self.allow_list = allow_list
        if authz_public_key is not None:
            self.authz_public_key = authz_public_key
        if application_service_uri is not None:
            self.application_service_uri = application_service_uri
        if tunnel_uri is not None:
            self.tunnel_uri = tunnel_uri
        if service_forwarders is not None:
            self.service_forwarders = service_forwarders
        if from_service_forwarders is not None:
            self.from_service_forwarders = from_service_forwarders

    @property
    def local_authentication_enabled(self):
        """Gets the local_authentication_enabled of this AgentConnectorInfo.  # noqa: E501

        Determines whether or not the agent will expose an endpoint for local authentication  # noqa: E501

        :return: The local_authentication_enabled of this AgentConnectorInfo.  # noqa: E501
        :rtype: bool
        """
        return self._local_authentication_enabled

    @local_authentication_enabled.setter
    def local_authentication_enabled(self, local_authentication_enabled):
        """Sets the local_authentication_enabled of this AgentConnectorInfo.

        Determines whether or not the agent will expose an endpoint for local authentication  # noqa: E501

        :param local_authentication_enabled: The local_authentication_enabled of this AgentConnectorInfo.  # noqa: E501
        :type: bool
        """

        self._local_authentication_enabled = local_authentication_enabled

    @property
    def connections_info(self):
        """Gets the connections_info of this AgentConnectorInfo.  # noqa: E501

        The list of connections associated with this agent  # noqa: E501

        :return: The connections_info of this AgentConnectorInfo.  # noqa: E501
        :rtype: list[AgentConnectorConnectionInfo]
        """
        return self._connections_info

    @connections_info.setter
    def connections_info(self, connections_info):
        """Sets the connections_info of this AgentConnectorInfo.

        The list of connections associated with this agent  # noqa: E501

        :param connections_info: The connections_info of this AgentConnectorInfo.  # noqa: E501
        :type: list[AgentConnectorConnectionInfo]
        """

        self._connections_info = connections_info

    @property
    def allow_list(self):
        """Gets the allow_list of this AgentConnectorInfo.  # noqa: E501


        :return: The allow_list of this AgentConnectorInfo.  # noqa: E501
        :rtype: AllowMapCompiled
        """
        return self._allow_list

    @allow_list.setter
    def allow_list(self, allow_list):
        """Sets the allow_list of this AgentConnectorInfo.


        :param allow_list: The allow_list of this AgentConnectorInfo.  # noqa: E501
        :type: AllowMapCompiled
        """

        self._allow_list = allow_list

    @property
    def authz_public_key(self):
        """Gets the authz_public_key of this AgentConnectorInfo.  # noqa: E501

        The PEM encoded public key used for validating bearer tokens  # noqa: E501

        :return: The authz_public_key of this AgentConnectorInfo.  # noqa: E501
        :rtype: str
        """
        return self._authz_public_key

    @authz_public_key.setter
    def authz_public_key(self, authz_public_key):
        """Sets the authz_public_key of this AgentConnectorInfo.

        The PEM encoded public key used for validating bearer tokens  # noqa: E501

        :param authz_public_key: The authz_public_key of this AgentConnectorInfo.  # noqa: E501
        :type: str
        """

        self._authz_public_key = authz_public_key

    @property
    def application_service_uri(self):
        """Gets the application_service_uri of this AgentConnectorInfo.  # noqa: E501

        The URI this connector will establish as the destination URI for service forwarder requests. An agent would request a certificate for the hostname provided as part of the URI for other connectors to establish a TLS connection to this connector.   # noqa: E501

        :return: The application_service_uri of this AgentConnectorInfo.  # noqa: E501
        :rtype: str
        """
        return self._application_service_uri

    @application_service_uri.setter
    def application_service_uri(self, application_service_uri):
        """Sets the application_service_uri of this AgentConnectorInfo.

        The URI this connector will establish as the destination URI for service forwarder requests. An agent would request a certificate for the hostname provided as part of the URI for other connectors to establish a TLS connection to this connector.   # noqa: E501

        :param application_service_uri: The application_service_uri of this AgentConnectorInfo.  # noqa: E501
        :type: str
        """

        self._application_service_uri = application_service_uri

    @property
    def tunnel_uri(self):
        """Gets the tunnel_uri of this AgentConnectorInfo.  # noqa: E501

        The URI this connector uses to establish its tunnels.  # noqa: E501

        :return: The tunnel_uri of this AgentConnectorInfo.  # noqa: E501
        :rtype: str
        """
        return self._tunnel_uri

    @tunnel_uri.setter
    def tunnel_uri(self, tunnel_uri):
        """Sets the tunnel_uri of this AgentConnectorInfo.

        The URI this connector uses to establish its tunnels.  # noqa: E501

        :param tunnel_uri: The tunnel_uri of this AgentConnectorInfo.  # noqa: E501
        :type: str
        """

        self._tunnel_uri = tunnel_uri

    @property
    def service_forwarders(self):
        """Gets the service_forwarders of this AgentConnectorInfo.  # noqa: E501

        The list of service forwarders associated with this connector.  # noqa: E501

        :return: The service_forwarders of this AgentConnectorInfo.  # noqa: E501
        :rtype: list[ServiceForwarder]
        """
        return self._service_forwarders

    @service_forwarders.setter
    def service_forwarders(self, service_forwarders):
        """Sets the service_forwarders of this AgentConnectorInfo.

        The list of service forwarders associated with this connector.  # noqa: E501

        :param service_forwarders: The service_forwarders of this AgentConnectorInfo.  # noqa: E501
        :type: list[ServiceForwarder]
        """

        self._service_forwarders = service_forwarders

    @property
    def from_service_forwarders(self):
        """Gets the from_service_forwarders of this AgentConnectorInfo.  # noqa: E501

        The list of service forwarders that are forwarded to this connector.  # noqa: E501

        :return: The from_service_forwarders of this AgentConnectorInfo.  # noqa: E501
        :rtype: list[ServiceForwarder]
        """
        return self._from_service_forwarders

    @from_service_forwarders.setter
    def from_service_forwarders(self, from_service_forwarders):
        """Sets the from_service_forwarders of this AgentConnectorInfo.

        The list of service forwarders that are forwarded to this connector.  # noqa: E501

        :param from_service_forwarders: The from_service_forwarders of this AgentConnectorInfo.  # noqa: E501
        :type: list[ServiceForwarder]
        """

        self._from_service_forwarders = from_service_forwarders

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentConnectorInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AgentConnectorInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.08
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.authentication_document import AuthenticationDocument  # noqa: E501
from agilicus_api.rest import ApiException

class TestAuthenticationDocument(unittest.TestCase):
    """AuthenticationDocument unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AuthenticationDocument
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.authentication_document.AuthenticationDocument()  # noqa: E501
        if include_optional :
            return AuthenticationDocument(
                metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                spec = agilicus_api.models.authentication_document_spec.AuthenticationDocumentSpec(
                    user_id = 'asdfghjklmn123', 
                    org_id = 'asdfghjklmn123', 
                    auth_issuer_url = 'https://auth.cloud.egov.city', 
                    expiry = '2002-10-02T10:00-05:00', ), 
                status = agilicus_api.models.authentication_document_status.AuthenticationDocumentStatus(
                    issuer = 'urn:agilicus:authentication_document:abc123', 
                    audience = 'urn:agilicus:api:tokens', 
                    key = '-----BEGIN PRIVATE KEY-----\nActualKeyContents\n-----END PRIVATE KEY-----\n', )
            )
        else :
            return AuthenticationDocument(
                spec = agilicus_api.models.authentication_document_spec.AuthenticationDocumentSpec(
                    user_id = 'asdfghjklmn123', 
                    org_id = 'asdfghjklmn123', 
                    auth_issuer_url = 'https://auth.cloud.egov.city', 
                    expiry = '2002-10-02T10:00-05:00', ),
        )

    def testAuthenticationDocument(self):
        """Test AuthenticationDocument"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.08
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class AgentConnectorTransportStats(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'active_connections': 'int',
        'target_number_connections': 'int',
        'connection_start_count': 'int',
        'connection_stop_count': 'int'
    }

    attribute_map = {
        'active_connections': 'active_connections',
        'target_number_connections': 'target_number_connections',
        'connection_start_count': 'connection_start_count',
        'connection_stop_count': 'connection_stop_count'
    }

    def __init__(self, active_connections=None, target_number_connections=None, connection_start_count=None, connection_stop_count=None, local_vars_configuration=None):  # noqa: E501
        """AgentConnectorTransportStats - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._active_connections = None
        self._target_number_connections = None
        self._connection_start_count = None
        self._connection_stop_count = None
        self.discriminator = None

        self.active_connections = active_connections
        self.target_number_connections = target_number_connections
        self.connection_start_count = connection_start_count
        self.connection_stop_count = connection_stop_count

    @property
    def active_connections(self):
        """Gets the active_connections of this AgentConnectorTransportStats.  # noqa: E501

        The number of currently active connections.   # noqa: E501

        :return: The active_connections of this AgentConnectorTransportStats.  # noqa: E501
        :rtype: int
        """
        return self._active_connections

    @active_connections.setter
    def active_connections(self, active_connections):
        """Sets the active_connections of this AgentConnectorTransportStats.

        The number of currently active connections.   # noqa: E501

        :param active_connections: The active_connections of this AgentConnectorTransportStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and active_connections is None:  # noqa: E501
            raise ValueError("Invalid value for `active_connections`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                active_connections is not None and active_connections < 0):  # noqa: E501
            raise ValueError("Invalid value for `active_connections`, must be a value greater than or equal to `0`")  # noqa: E501

        self._active_connections = active_connections

    @property
    def target_number_connections(self):
        """Gets the target_number_connections of this AgentConnectorTransportStats.  # noqa: E501

        The number of connections which should be in an active state. Note that this may be less than active_connections if the AgentConnector is currently applying configuration changes. It may be more than active_connections if there is a connectivity issue, or connections are first starting.   # noqa: E501

        :return: The target_number_connections of this AgentConnectorTransportStats.  # noqa: E501
        :rtype: int
        """
        return self._target_number_connections

    @target_number_connections.setter
    def target_number_connections(self, target_number_connections):
        """Sets the target_number_connections of this AgentConnectorTransportStats.

        The number of connections which should be in an active state. Note that this may be less than active_connections if the AgentConnector is currently applying configuration changes. It may be more than active_connections if there is a connectivity issue, or connections are first starting.   # noqa: E501

        :param target_number_connections: The target_number_connections of this AgentConnectorTransportStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and target_number_connections is None:  # noqa: E501
            raise ValueError("Invalid value for `target_number_connections`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                target_number_connections is not None and target_number_connections < 0):  # noqa: E501
            raise ValueError("Invalid value for `target_number_connections`, must be a value greater than or equal to `0`")  # noqa: E501

        self._target_number_connections = target_number_connections

    @property
    def connection_start_count(self):
        """Gets the connection_start_count of this AgentConnectorTransportStats.  # noqa: E501

        The number of times connections have been started   # noqa: E501

        :return: The connection_start_count of this AgentConnectorTransportStats.  # noqa: E501
        :rtype: int
        """
        return self._connection_start_count

    @connection_start_count.setter
    def connection_start_count(self, connection_start_count):
        """Sets the connection_start_count of this AgentConnectorTransportStats.

        The number of times connections have been started   # noqa: E501

        :param connection_start_count: The connection_start_count of this AgentConnectorTransportStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and connection_start_count is None:  # noqa: E501
            raise ValueError("Invalid value for `connection_start_count`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                connection_start_count is not None and connection_start_count < 0):  # noqa: E501
            raise ValueError("Invalid value for `connection_start_count`, must be a value greater than or equal to `0`")  # noqa: E501

        self._connection_start_count = connection_start_count

    @property
    def connection_stop_count(self):
        """Gets the connection_stop_count of this AgentConnectorTransportStats.  # noqa: E501

        The number of times connections have stopped   # noqa: E501

        :return: The connection_stop_count of this AgentConnectorTransportStats.  # noqa: E501
        :rtype: int
        """
        return self._connection_stop_count

    @connection_stop_count.setter
    def connection_stop_count(self, connection_stop_count):
        """Sets the connection_stop_count of this AgentConnectorTransportStats.

        The number of times connections have stopped   # noqa: E501

        :param connection_stop_count: The connection_stop_count of this AgentConnectorTransportStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and connection_stop_count is None:  # noqa: E501
            raise ValueError("Invalid value for `connection_stop_count`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                connection_stop_count is not None and connection_stop_count < 0):  # noqa: E501
            raise ValueError("Invalid value for `connection_stop_count`, must be a value greater than or equal to `0`")  # noqa: E501

        self._connection_stop_count = connection_stop_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentConnectorTransportStats):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AgentConnectorTransportStats):
            return True

        return self.to_dict() != other.to_dict()
